@@ -36,18 +36,19 @@ async def transUIGF(uid: str, gachaLogs: Dict) -> Dict:
         "info": {
             "uid": uid,
             "lang": "zh-cn",
-            "export_time": datetime_with_tz().strftime("%Y-%m-%d %H:%M:%S"),
+            "uigf_version": "v2.3",
             "export_timestamp": int(time()),
+            "export_time": datetime_with_tz().strftime("%Y-%m-%d %H:%M:%S"),
             "export_app": "nonebot-plugin-gachalogs",
-            "export_app_version": "v0.2.0",
-            "uigf_version": "v2.2",
+            "export_app_version": "v0.2.12",
         },
         "list": [],
     }
     # 转换数据
     for banner in GACHA_TYPE:
         gachaLog = gachaLogs.get(banner, [])
-        gachaLog = sorted(gachaLog, key=lambda i: i["time"], reverse=False)
+        gachaLog = sorted(gachaLog, key=lambda i: i["time"], reverse=True)
+        gachaLog.reverse()
         for item in gachaLog:
             item["uigf_gacha_type"] = banner
         uigf["list"].extend(gachaLog)
